/**
 * jQuery Plugin to support modal videos
 * Author: Aaron Dickey, Dan Dietz
 */
(function($){
    var pluginName = 'video';

    function Video( element, options ) {
        this.el = element;
        this.$el = $(element);
        this.splashImage = this.$el.find("img");
        this._defaults = {videoId: this.splashImage.attr('title') || "wyz_2DEah4o"};
        this.options = $.extend({}, this._defaults, options);
        this._name = pluginName;

        this.init();
    }

    Video.prototype.init = function(){
        var self = this;

        // Play event handler
        self.$el.on('click', function(e){
            e.preventDefault();
            self.play();
        });
    };

    Video.prototype.play = function(){
      var height = this.splashImage.height();
      var videoUrl = 'https://www.youtube.com/embed/' + this.options.videoId;
      var videoQuery = $.param({autoplay: 1, autohide: 1});

      // Build the iframe
      var videoFrame = '<iframe class="vidPlayer" frameborder="0" src="' + videoUrl + '?' + videoQuery + '" '
          + 'style="width:100%; height:' + (height)  + 'px" allowfullscreen="allowfullscreen" '
          + 'mozallowfullscreen="mozallowfullscreen" msallowfullscreen="msallowfullscreen" '
          + 'oallowfullscreen="oallowfullscreen" webkitallowfullscreen="webkitallowfullscreen"></iframe>';

      // Render video iframe
      this.$el
          .off('click')
          .addClass('playing')
          .html(videoFrame);
    };

    Video.prototype.clear = function(){
        // Render the splash image
        var self = this;
        this.$el
            .on('click', function(){self.play()})
            .removeClass('playing')
            .html(this.splashImage);
    };


    $.fn[pluginName] = function ( options ) {
        return this.each(function () {
            if (!$.data(this, 'plugin_' + pluginName)) {
                $.data(this, 'plugin_' + pluginName,
                    new Video( this, options ));
            }
        });
    }
}(jQuery));
